@@ -1,6 +1,8 @@
 import argparse
 import os
 import subprocess
+from pathlib import Path
+from shutil import which
 
 from platform import python_version
 from py3status.version import version
@@ -11,22 +13,12 @@ def parse_cli_args():
     Parse the command line arguments
     """
     # get config paths
-    home_path = os.path.expanduser("~")
-    xdg_home_path = os.environ.get("XDG_CONFIG_HOME", "{}/.config".format(home_path))
-    xdg_dirs_path = os.environ.get("XDG_CONFIG_DIRS", "/etc/xdg")
-
-    # get i3status path
-    try:
-        with open(os.devnull, "w") as devnull:
-            command = ["which", "i3status"]
-            i3status_path = (
-                subprocess.check_output(command, stderr=devnull).decode().strip()
-            )
-    except subprocess.CalledProcessError:
-        i3status_path = None
+    home_path = Path.home()
+    xdg_home_path = Path(os.environ.get("XDG_CONFIG_HOME", home_path / ".config"))
+    xdg_dirs_path = Path(os.environ.get("XDG_CONFIG_DIRS", "/etc/xdg"))
 
     # get window manager
-    with open(os.devnull, "w") as devnull:
+    with Path(os.devnull).open("w") as devnull:
         if subprocess.call(["pgrep", "i3"], stdout=devnull) == 0:
             wm = "i3"
         else:
@@ -35,17 +27,17 @@ def parse_cli_args():
     # i3status config file default detection
     # respect i3status' file detection order wrt issue #43
     i3status_config_file_candidates = [
-        "{}/py3status/config".format(xdg_home_path),
-        "{}/i3status/config".format(xdg_home_path),
-        "{}/i3/i3status.conf".format(xdg_home_path),  # custom
-        "{}/.i3status.conf".format(home_path),
-        "{}/.i3/i3status.conf".format(home_path),  # custom
-        "{}/i3status/config".format(xdg_dirs_path),
-        "/etc/i3status.conf",
+        xdg_home_path / "py3status/config",
+        xdg_home_path / "i3status/config",
+        xdg_home_path / "i3/i3status.conf",  # custom
+        home_path / ".i3status.conf",
+        home_path / ".i3/i3status.conf",  # custom
+        xdg_dirs_path / "i3status/config",
+        Path("/etc/i3status.conf"),
     ]
-    for fn in i3status_config_file_candidates:
-        if os.path.isfile(fn):
-            i3status_config_file_default = fn
+    for path in i3status_config_file_candidates:
+        if path.exists():
+            i3status_config_file_default = path
             break
     else:
         # if files does not exists, defaults to ~/.i3/i3status.conf
@@ -54,16 +46,14 @@ def parse_cli_args():
     class Parser(argparse.ArgumentParser):
         # print usages and exit on errors
         def error(self, message):
-            print("\x1b[1;31merror: \x1b[0m{}".format(message))
+            print(f"\x1b[1;31merror: \x1b[0m{message}")
             self.print_help()
             self.exit(1)
 
         # hide choices on errors
         def _check_value(self, action, value):
             if action.choices is not None and value not in action.choices:
-                raise argparse.ArgumentError(
-                    action, "invalid choice: '{}'".format(value)
-                )
+                raise argparse.ArgumentError(action, f"invalid choice: '{value}'")
 
     class HelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         def _format_action_invocation(self, action):
@@ -90,7 +80,7 @@ def parse_cli_args():
         dest="i3status_config_path",
         help="load config",
         metavar="FILE",
-        type=str,
+        type=Path,
     )
     parser.add_argument(
         "-d",
@@ -112,6 +102,7 @@ def parse_cli_args():
         dest="include_paths",
         help="append additional user-defined module paths",
         metavar="PATH",
+        type=Path,
     )
     parser.add_argument(
         "-l",
@@ -120,7 +111,7 @@ def parse_cli_args():
         dest="log_file",
         help="enable logging to FILE",
         metavar="FILE",
-        type=str,
+        type=Path,
     )
     parser.add_argument(
         "-s",
@@ -150,11 +141,11 @@ def parse_cli_args():
         "-u",
         "--i3status",
         action="store",
-        default=i3status_path,
+        default=which("i3status") or "i3status",
         dest="i3status_path",
         help="specify i3status path",
         metavar="PATH",
-        type=str,
+        type=Path,
     )
     parser.add_argument(
         "-v",
@@ -194,23 +185,19 @@ def parse_cli_args():
         "sway": {"msg": "swaymsg", "nag": "swaynag"},
     }[options.wm]
 
-    # make it i3status if None
-    if not options.i3status_path:
-        options.i3status_path = "i3status"
-
     # make include path to search for user modules if None
     if not options.include_paths:
         options.include_paths = [
-            "{}/py3status/modules".format(xdg_home_path),
-            "{}/i3status/py3status".format(xdg_home_path),
-            "{}/i3/py3status".format(xdg_home_path),
-            "{}/.i3/py3status".format(home_path),
+            xdg_home_path / "py3status/modules",
+            xdg_home_path / "i3status/py3status",
+            xdg_home_path / "i3/py3status",
+            home_path / ".i3/py3status",
         ]
 
     include_paths = []
     for path in options.include_paths:
-        path = os.path.abspath(path)
-        if os.path.isdir(path) and os.listdir(path):
+        path = path.resolve()
+        if path.is_dir() and any(path.iterdir()):
             include_paths.append(path)
     options.include_paths = include_paths
 
