@@ -1,14 +1,14 @@
 import sys
+import time
 
 from copy import deepcopy
 from json import loads
-from datetime import datetime, timedelta, tzinfo
+from datetime import datetime, timezone
 from subprocess import Popen
 from subprocess import PIPE
 from signal import SIGTSTP, SIGSTOP, SIGUSR1, SIG_IGN, signal
 from tempfile import NamedTemporaryFile
 from threading import Thread
-from time import time
 
 from py3status.profiling import profile
 from py3status.py3 import Py3
@@ -22,32 +22,6 @@ from py3status.constants import (
 )
 
 
-class Tz(tzinfo):
-    """
-    Timezone info for creating dates.
-    This is mainly so we can use %Z in strftime
-    """
-
-    MAX_OFFSET = timedelta(hours=23, minutes=59)
-
-    def __init__(self, name, offset):
-        # issue 1375 race issue on suspend
-        if abs(offset) > self.MAX_OFFSET:
-            raise ValueError("Invalid offset")
-        self._offset = offset
-        self._name = name
-
-    def utcoffset(self, dt):
-        return self._offset
-
-    def tzname(self, dt):
-        return str(self._name)
-
-    def dst(self, dt):
-        # we have no idea if daylight savings, so just say no kids
-        return timedelta(0)
-
-
 class I3statusModule:
     """
     This a wrapper for i3status items so that they mirror some of the methods
@@ -78,6 +52,10 @@ class I3statusModule:
         self.i3status = i3status
         py3_wrapper = i3status.py3_wrapper
 
+        markup = py3_wrapper.config["py3_config"]["general"].get("markup")
+        if markup:
+            self.item["markup"] = markup
+
         # color map for if color good/bad etc are set for the module
         color_map = {}
         py3_config = py3_wrapper.config["py3_config"]
@@ -112,7 +90,7 @@ class I3statusModule:
         elif "%T" in time_format:
             # seconds included in "%H:%M:%S"
             time_delta = 1
-        elif "%c" in time_format:
+        elif "%c" in time_format or "%+" in time_format:
             # Locale's appropriate date and time representation
             time_delta = 1
         elif "%X" in time_format:
@@ -123,7 +101,7 @@ class I3statusModule:
         self.time_delta = time_delta
 
     def __repr__(self):
-        return "<I3statusModule {}>".format(self.module_name)
+        return f"<I3statusModule {self.module_name}>"
 
     def get_latest(self):
         return [self.item.copy()]
@@ -158,7 +136,7 @@ class I3statusModule:
             self.item = item
         else:
             # If no timezone or a minute has passed update timezone
-            t = time()
+            t = time.perf_counter()
             if self.time_zone_check_due < t:
                 # If we are late for our timezone update then schedule the next
                 # update to happen when we next get new data from i3status
@@ -237,7 +215,7 @@ class I3statusModule:
         ) - datetime(utcnow.year, utcnow.month, utcnow.day, utcnow.hour, utcnow.minute)
         # create our custom timezone
         try:
-            self.tz = Tz(i3s_time_tz, delta)
+            self.tz = timezone(delta, i3s_time_tz)
         except ValueError:
             return False
         return True
@@ -260,7 +238,7 @@ class I3status(Thread):
         self.json_list = None
         self.json_list_ts = None
         self.last_output = None
-        self.last_refresh_ts = time()
+        self.last_refresh_ts = time.perf_counter()
         self.lock = py3_wrapper.lock
         self.new_update = False
         self.py3_config = py3_wrapper.config["py3_config"]
@@ -331,12 +309,12 @@ class I3status(Thread):
         """
         # order += ...
         for module in self.py3_config["i3s_modules"]:
-            self.write_in_tmpfile('order += "%s"\n' % module, tmpfile)
+            self.write_in_tmpfile(f'order += "{module}"\n', tmpfile)
         self.write_in_tmpfile("\n", tmpfile)
         # config params for general section and each module
         for section_name in ["general"] + self.py3_config["i3s_modules"]:
             section = self.py3_config[section_name]
-            self.write_in_tmpfile("%s {\n" % section_name, tmpfile)
+            self.write_in_tmpfile(f"{section_name} {{\n", tmpfile)
             for key, value in section.items():
                 # don't include color values except in the general section
                 if key.startswith("color"):
@@ -353,8 +331,8 @@ class I3status(Thread):
                     if key == "format_time":
                         continue
                 if isinstance(value, bool):
-                    value = "{}".format(value).lower()
-                self.write_in_tmpfile('    {} = "{}"\n'.format(key, value), tmpfile)
+                    value = f"{value}".lower()
+                self.write_in_tmpfile(f'    {key} = "{value}"\n', tmpfile)
             self.write_in_tmpfile("}\n\n", tmpfile)
         tmpfile.flush()
 
@@ -365,18 +343,18 @@ class I3status(Thread):
 
     def refresh_i3status(self):
         # refresh i3status.  This is rate limited
-        if time() > (self.last_refresh_ts + 0.1):
+        if time.perf_counter() > (self.last_refresh_ts + 0.1):
             if self.py3_wrapper.config["debug"]:
                 self.py3_wrapper.log("refreshing i3status")
             if self.i3status_pipe:
                 self.i3status_pipe.send_signal(SIGUSR1)
-            self.last_refresh_ts = time()
+            self.last_refresh_ts = time.perf_counter()
 
     @profile
     def run(self):
         # if the i3status process dies we want to restart it.
         # We give up restarting if we have died too often
-        for x in range(10):
+        for _ in range(10):
             if not self.py3_wrapper.running:
                 break
             self.spawn_i3status()
@@ -403,7 +381,7 @@ class I3status(Thread):
                 )
 
                 self.py3_wrapper.log(
-                    "i3status spawned using config file {}".format(tmpfile.name)
+                    f"i3status spawned using config file {tmpfile.name}"
                 )
 
                 self.poller_inp = IOPoller(i3status_pipe.stdout)
@@ -432,9 +410,9 @@ class I3status(Thread):
                             if code is not None:
                                 msg = "i3status died"
                                 if err:
-                                    msg += " and said: {}".format(err)
+                                    msg += f" and said: {err}"
                                 else:
-                                    msg += " with code {}".format(code)
+                                    msg += f" with code {code}"
                                 raise OSError(msg)
                 except OSError:
                     err = sys.exc_info()[1]
